# http.kafka.karapace

This simple http.kafka.karapace example illustrates how to configure Karapace Schema Registry in zilla to validate messages while produce and fetch to a Kafka topic.

## Setup

```bash
./setup.sh
```

### Register Schema

```bash
curl 'http://localhost:8081/subjects/core-paymenthub-simple-pay-ipn-request-value/versions' \
--header 'Content-Type: application/json' \
--data '{
  "schema":
    "{\"fields\":[{\"name\":\"orderRef\",\"type\":\"string\"},{\"name\":\"method\",\"type\":\"string\"}],\"name\":\"Event\",\"namespace\":\"io.aklivity.example\",\"type\":\"record\"}",
  "schemaType": "AVRO"
}'
curl 'http://localhost:8081/subjects/core-paymenthub-simple-pay-ipn-response-value/versions' \
--header 'Content-Type: application/json' \
--data '{
  "schema":
    "{\"fields\":[{\"name\":\"orderRef\",\"type\":\"string\"},{\"name\":\"method\",\"type\":\"string\"}],\"name\":\"Event\",\"namespace\":\"io.aklivity.example\",\"type\":\"record\"}",
  "schemaType": "AVRO"
}'
```

## Verify behavior for a valid event

1. `POST` new object as JSON request.

  ```bash
  curl -k -v http://localhost:8080/api/v1/paymenthub/simple-pay/ipn  -H 'Content-Type: application/json' -d '{ "orderRef": "150-6622c5591a320", "method": "CARD" }'
  ```

1. find the `payload` and `zilla:correlation-id` header value from the in flight request

  ```bash
  kcat -C -b localhost:9092 -t core-paymenthub-simple-pay-ipn-request -J -u | jq .
  ```

1. `produce` the avro schema payload onto the response topic with the correct

  ```bash
  echo <message_payload> | \
  kcat -P \
      -b localhost:9092 \
      -t core-paymenthub-simple-pay-ipn-response \
      -k "abc123" \
      -H ":status=200" \
      -H "zilla:correlation-id=<correlation_id_header_value>"
  ```

1. `POST` request finishes with valid JSON.

1. `GET` request to fetch all records as JSON.

  ```bash
  curl -k -v http://localhost:8080/api/v1/paymenthub/simple-pay/ipn
  ```

## Teardown

The `teardown.sh` script stops port forwarding, uninstalls Zilla and Kafka and deletes the namespace.

```bash
./teardown.sh
```
